<?xml version="1.0"?>

<!-- 11/11/04 changed from xsl:value-of select="'2.1'" to xsl:value-of select="'2.0'" -->
<!-- 
	******************************************************************
	**  IBM WebSphere Voice Toolkit         
	**  (C) COPYRIGHT International Business Machines Corp. 2003,2007
	**  All Rights Reserved * Licensed Materials - Property of IBM
	******************************************************************
-->

<xsl:stylesheet version="1.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xalan="http://xml.apache.org/xslt" 
xmlns="http://www.w3.org/2001/vxml" 
xmlns:vxml="http://www.w3.org/2001/vxml">


	<!-- Set Output Method -->

	<xsl:output method="xml" />
	<xsl:namespace-alias stylesheet-prefix="" result-prefix="#default" />

	<!-- Set Lang5 and vxmlVersion Parameters -->

	<xsl:param name="lang5" />
	<xsl:param name="vxmlVersion" />

	<!-- Process Root and All Comments -->
	<xsl:template match="/">
		<xsl:apply-templates></xsl:apply-templates>
	</xsl:template>
	
	<!-- 
	<xsl:template match="/comment()">
		<xsl:copy-of select="current()" />
		<xsl:text>&#10;</xsl:text>
	</xsl:template>
	-->

	<xsl:template match="vxml:vxml">
		<!-- <xsl:text>&#10;</xsl:text> -->
		<xsl:copy>
			<!-- Create new root element "vxml".  Copy any "lang" attributes to the new "xml:lang" attribute and modify. -->
			<!-- Copy any "base" attributes to the new "xml:base" attribute. -->
			<!-- Change "version". -->
			<xsl:if test="current()/@base">
				<xsl:attribute name="xml:base">
					<xsl:value-of select="current()/@base" />
				</xsl:attribute>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="current()/@lang">
					<xsl:attribute name="xml:lang">
						<xsl:value-of select="translate(current()/@lang, '_', '-')" />
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="xml:lang">
						<xsl:value-of select="$lang5" />
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="current()/@application">
				<xsl:attribute name="application">
					<xsl:value-of select="current()/@application" />
				</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="version">
 <!-- commented <xsl:value-of select="'2.0'" /> -->
				<xsl:value-of select="$vxmlVersion" />
			</xsl:attribute>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:meta">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>




	<!-- Process Dialog Elements -->

	<xsl:template match="vxml:form | vxml:menu">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:choice">
		<!-- If the "caching" attribute exists, re-create the "choice" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="choice">
					<xsl:for-each select="@*[not(name(.)='caching')]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>




	<!-- Process Prompts -->

	<xsl:template match="vxml:prompt | vxml:enumerate">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:reprompt">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>




	<!-- Process Fields -->

	<xsl:template match="vxml:field | vxml:option | vxml:initial">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:block">
		<!-- If any of the following children elements exist, put everything under a "prompt" child element. -->
		<!-- If none of them exist as a child element, copy everything as is. -->
		<xsl:choose>
			<xsl:when test="vxml:break | vxml:div | vxml:emp | vxml:pros | vxml:sayas | vxml:ibmvoice | vxml:property">
				<!-- Provide comments in code, if applicable -->
				<xsl:text>&#10;</xsl:text>
				<xsl:comment>%VXMLCOMMENT_03%</xsl:comment>
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="vxml:assign | vxml:clear | vxml:disconnect | vxml:exit | vxml:goto | vxml:if | vxml:else | vxml:prompt | vxml:reprompt | vxml:return | vxml:script | vxml:submit | vxml:throw | vxml:var">
					<xsl:comment>%VXMLCOMMENT_04%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:text>&#10;</xsl:text>
					<xsl:element name="prompt">
						<xsl:if test="vxml:property/@name = 'bargein'">
							<xsl:attribute name="bargein">
								<xsl:value-of select="'true'" />
							</xsl:attribute>
						</xsl:if>
						<xsl:apply-templates></xsl:apply-templates>
					</xsl:element>
					<xsl:text>&#10;</xsl:text>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:assign | vxml:clear | vxml:var">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>


	<xsl:template match="vxml:value">
		<xsl:choose>
			<xsl:when test="current()/@class">
				<!-- Provide comments in code, if applicable -->
				<xsl:text>&#10;</xsl:text>
				<xsl:comment>%VXMLCOMMENT_05%</xsl:comment>
				<xsl:text>&#10;</xsl:text>
				<!-- End of comments -->
				<xsl:element name="say-as">
					<xsl:attribute name="interpret-as">
						<xsl:value-of select="concat('vxml:', current()/@class)" />
					</xsl:attribute>
					<xsl:copy>
						<xsl:attribute name="expr">
							<xsl:value-of select="current()/@expr" />
						</xsl:attribute>
					</xsl:copy>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:attribute name="expr">
						<xsl:value-of select="current()/@expr" />
					</xsl:attribute>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>




	<!-- Process Events -->


	<xsl:template match="vxml:catch | vxml:error | vxml:help | vxml:noinput | vxml:nomatch">
		<!-- If any of the following children elements exist, put everything under a "prompt" child element. -->
		<!-- If none of them exist as a child element, copy everything as is. -->
		<xsl:choose>
			<xsl:when test="vxml:break | vxml:div | vxml:emp | vxml:pros | vxml:sayas | vxml:ibmvoice | vxml:property">
				<!-- Provide comments in code, if applicable -->
				<xsl:text>&#10;</xsl:text>
				<xsl:comment>%VXMLCOMMENT_03%</xsl:comment>
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="vxml:assign | vxml:clear | vxml:disconnect | vxml:exit | vxml:goto | vxml:if | vxml:else | vxml:prompt | vxml:reprompt | vxml:return | vxml:script | vxml:submit | vxml:throw | vxml:var">
					<xsl:comment>%VXMLCOMMENT_04%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:text>&#10;</xsl:text>
					<xsl:element name="prompt">
						<xsl:if test="vxml:property/@name = 'bargein'">
							<xsl:attribute name="bargein">
								<xsl:value-of select="'true'" />
							</xsl:attribute>
						</xsl:if>
						<xsl:apply-templates></xsl:apply-templates>
					</xsl:element>
					<xsl:text>&#10;</xsl:text>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:link">
		<!-- If the "caching" attribute exists, re-create the "link" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="link">
					<xsl:for-each select="@*[not(name(.)='caching')]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:throw">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>




	<!-- Process Audio Output -->

	<xsl:template match="vxml:audio">
		<!-- If the "caching" attribute exists, re-create the "audio" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="audio">
					<xsl:for-each select="@*[not(name(.)='caching')]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:break">
		<!-- Depending on what attributes we have, copy the appropriate ones to the "time" attribute.  Default to "msecs" value if both exist. -->
		<xsl:copy>
			<xsl:if test="(current()/@size) or (current()/@time) or (current()/@msecs)">
				<xsl:attribute name="time">
					<xsl:choose>
						<xsl:when test="current()/@msecs">
							<xsl:value-of select="concat(current()/@msecs, 'ms')" />
						</xsl:when>
						<xsl:when test="current()/@time">
							<xsl:value-of select="current()/@time" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="current()/@size" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:div">
		<!-- Change the element to either "p" or "s" depending on the value of "type". -->
		<xsl:choose>
			<xsl:when test="current()/@type">
				<xsl:if test="current()/@type = 'sentence'">
					<xsl:element name="s">
						<xsl:value-of select="div" />
						<xsl:apply-templates></xsl:apply-templates>
					</xsl:element>
				</xsl:if>
				<xsl:if test="current()/@type = 'paragraph'">
					<xsl:element name="p">
						<xsl:value-of select="div" />
						<xsl:apply-templates></xsl:apply-templates>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="s">
					<xsl:value-of select="div" />
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:emp">
		<!-- Change element name to "emphasis" then copy all attributes. -->
		<xsl:element name="emphasis">
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:element>
	</xsl:template>


	<xsl:template match="vxml:pros">
		<!-- Change element name to "prosody" then copy all attributes except "vol" which changes to "volume" if it exists. -->
		<xsl:element name="prosody">
			<xsl:for-each select="@*[not(name(.)='vol')]">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:if test="current()/@vol">
				<xsl:attribute name="volume">
					<xsl:value-of select="current()/@vol" />
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:element>
	</xsl:template>


	<xsl:template match="vxml:sayas">
		<!-- Change element to "say-as" and change value of "class" attribute to prepend "vxml:"  -->
		<xsl:element name="say-as">
			<xsl:choose>
				<xsl:when test="current()/@class">
					<xsl:attribute name="interpret-as">
						<xsl:value-of select="concat('vxml:', current()/@class)" />
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise></xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:element>
	</xsl:template>



	<!-- Process Audio Input -->

	<xsl:template match="vxml:dtmf">
		<!-- Replace with "grammar" element and add the "mode" attribute with value set to "dtmf". -->
		<xsl:element name="grammar">
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:attribute name="mode">
				<xsl:value-of select="'dtmf'" />
			</xsl:attribute>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:element>
	</xsl:template>


	<xsl:template match="vxml:record">
		<!-- No apparent changes are necessary - just copy it. -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>




	<!-- Process Call Control -->

	<xsl:template match="vxml:disconnect">
		<!-- No apparent changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>


	<xsl:template match="vxml:transfer">
		<!-- Copy everything except "dest" attribute with a value starting with "phone://". -->
		<!-- Re-create "dest" attribute and replace "phone://" with "tel:+". -->
		<xsl:choose>
			<xsl:when test="starts-with(current()/@dest, 'phone://')">
				<xsl:element name="transfer">
					<xsl:for-each select="@*[not(name(.)='dest')]">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:attribute name="dest">
						<xsl:value-of select="concat('tel:+', substring-after(current()/@dest, 'phone://'))" />
					</xsl:attribute>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>




	<!-- Process Control Flow -->

	<xsl:template match="vxml:if | vxml:filled">
		<!-- No apparent changes are necessary - just copy it. -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:elseif | vxml:else | vxml:exit | vxml:param | vxml:return">
		<!-- No apparent changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>


	<xsl:template match="vxml:goto">
		<!-- If the "caching" attribute exists, re-create the "goto" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="goto">
					<xsl:for-each select="@*[not(name(.)='caching')]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="current()" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:subdialog">
		<!-- If the "caching" or "modal" attribute exist, re-create the "subdialog" element not copying the "caching" or "modal" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", clear the value and re-create the attribute.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@modal) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@modal">
					<xsl:comment>%VXMLCOMMENT_06%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="subdialog">
					<xsl:for-each select="@*[(not(name(.)='caching')) and (not(name(.)='modal'))]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:submit">
		<!-- If the "caching" attribute exists, re-create the "submit" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="submit">
					<xsl:for-each select="@*[not(name(.)='caching')]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="current()" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>




	<!-- Process Miscellaneous -->

	<xsl:template match="vxml:object">
		<!-- If the "caching" attribute exists, re-create the "object" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@fetchaudio) | (current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchaudio">
					<xsl:comment>%VXMLCOMMENT_07%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="object">
					<xsl:for-each select="@*[(not(name(.)='fetchaudio')) and (not(name(.)='caching'))]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="vxml:property">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>


	<xsl:template match="vxml:script">
		<!-- If the "caching" attribute exists, re-create the "script" element while not copying the "caching" attribute.  In addition,  -->
		<!-- if the attribute "fetchhint" exists with the value set to "stream", do not carry it over.  -->
		<!-- We will copy all other attributes without any changes.  -->
		<xsl:choose>
			<xsl:when test="(current()/@caching) | (current()/@fetchhint)">
				<!-- Provide comments in the code, if applicable. -->
				<xsl:text>&#10;</xsl:text>
				<xsl:if test="current()/@caching">
					<xsl:comment>%VXMLCOMMENT_01%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<xsl:if test="current()/@fetchhint = 'stream'">
					<xsl:comment>%VXMLCOMMENT_02%</xsl:comment>
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
				<!-- End of comments -->
				<xsl:element name="script">
					<xsl:for-each select="@*[not(name(.)='caching')]">
						<xsl:choose>
							<xsl:when test="(name(.)= 'fetchhint') and (. = 'stream')"></xsl:when>
							<xsl:otherwise>
								<xsl:copy></xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:for-each select="current()/@*">
						<xsl:copy></xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates></xsl:apply-templates>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>




	<!-- Process Speech Recognition Grammar XML Format Extensions -->

	<xsl:template match="vxml:ruleref | vxml:lexicon | vxml:metadata">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy-of select="current()" />
	</xsl:template>


	<xsl:template match="vxml:token | vxml:tag | vxml:one-of | vxml:item | vxml:rule | vxml:example | vxml:grammar">
		<!-- No changes are necessary - just copy it. -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>




	<!-- Process IBM Extensions -->

	<xsl:template match="vxml:ibmvoice | vxml:ibmlexicon">
		<!-- Provide comments in the code. -->
		<xsl:text>&#10;</xsl:text>
		<xsl:comment>%VXMLCOMMENT_08%</xsl:comment>
		<xsl:text>&#10;</xsl:text>
		<!-- End of comments -->
		<xsl:copy>
			<xsl:for-each select="current()/@*">
				<xsl:copy></xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates></xsl:apply-templates>
		</xsl:copy>
	</xsl:template>


	<xsl:template match="vxml:word">
		<!-- Provide comments in the code. -->
		<xsl:text>&#10;</xsl:text>
		<xsl:comment>%VXMLCOMMENT_08%</xsl:comment>
		<xsl:text>&#10;</xsl:text>
		<!-- End of comments -->
		<xsl:copy-of select="current()" />
	</xsl:template>




	<!-- Process All Other Undefined Elements/Attributes -->

	<xsl:template match="node() | @*">
		<xsl:copy-of select="current()" />
	</xsl:template>


</xsl:stylesheet>